/*	$NetBSD: msg_131.c,v 1.4 2023/03/28 14:44:34 rillig Exp $	*/
# 3 "msg_131.c"

// Test for message: conversion to '%s' may sign-extend incorrectly [131]
// This message is not used.

typedef int dummy;
